# This file simply defines some help text used by shotGui.py.  It is placed
# here so it is easy to read and modify without having to wade through
# the GUI code.

# What is show from shotGui's menu Help->About
aboutShotGui = "PyShottab v1.0.2 - Copyright Dalhousie University, 2002-2003."

# What is shown from shotGui's menu Help->Help
shotGuiHelp = """PyShottab Quick Reference.
See the documentation (PDF) for detailed instructions and illustrations.

Description:  pyShottab is a multi-platform graphical program for making 
Dalhousie OBS SEGY shot tables quickly and easily.  It can import any format of 
text file for shotlog and navigation file, and can handle mulitple gigabyte size 
files.  This shot table is used with DOBS2SEGY2000 to create the SEGY 
files.

Usage:  After installing pyShottab, there should be an icon on the desktop 
(Windows) which runs shotGui (eg: C:\pyShottab\shotGui.exe).  To create a shot 
table, import the Shotlog and Navigation data and fill out the necessary 
information.  Save these parameters using the 'Save As' or 'Save' options in the 
File menu.  An existing parameter file can be opened later in the program, or 
edited in a text editor.  Click the 'Run' button to create the shotlog.

pyShottab can also be run from the command line using 'shotCreate' [the command 
would be ['shotCreate.exe parameterfile.ini'], which is ideal for doing batch 
processing (especially in Unix).  See documentation for detailed instructions. 

CRUISE ID: comments describing the OBS station.

OUTPUT SHOT TABLE FILE NAME: the file name 
out the output, click 'Choose' to choose a new or existing file.

SHOTLOG POSITION: use the position data (lat/long) in the Shotlog data, or the 
navigation data.  It is recommended to use the navigation data for shot 
positions.

SHOTLOG DATA: this button brings up a dialog for importing the Shotlog data, 
which describes the exact GPS timing of each shot.  This window has its own help 
dialog.

NAVIGATION DATA: this button brings up a dialog for importing the 
Navigation data, which describes the position of the ship relative to GPS time.  
This window also has its own help dialog.

HEADING INTERPOLATION (optional): use the option to calculate the ships heading 
during the shooting.  This will be used to correct for the GPS antenna - airgun 
offset.  If this option is turned off, there must be heading information present 
in the navigation data.  Heading information is not necessary if you will not be 
correcting for the antenna - airgun offset.

SHOT POSITION OFFSET (optional): use this option to correct for the offset 
between the GPS antenna and the airgun.  This requires ship's heading 
information from either the navigation data, or interpolated from the navigation 
data (previous option).  The values of the offset describe the offset behind 
(aft offset is positive), and the port/starboard offset (starboard is positive, 
port negative) of the airgun relative to the GPS antenna.  See the documentation 
(PDF) for an illustration.

RANGE SIGN (optional): check this box if you wish all ranges (offset from the 
OBS to the airgun) to be positive.  This is useful for complex surveys, in which 
the user will manually change the sign of the range in the shot table.

OBS POSITION:  the position of the OBS (decimal degrees). If OBS has not been 
relocated this is the drop position, otherwise it is the relocated position.

CENTRAL MERIDIAN:  the reference longitude for this study area usually in the 
center of the area. An integer value equally divisible by 3.

TIME OF CLOCK RESET: the time the OBS clock was turned on or reset (GMT).

OFFSET BETWEEN SHIP AND OBS: the initial offset between the ship's GPS clock 
and the OBS clock in milliseconds, prior to deployment.  This follows the same 
convention as the TOTAL CLOCK DRIFT.

TIME OF DRIFT CALIBRATION: the time that the 'post deployment offset' for the 
OBS was determined (GMT).

TOTAL CLOCK DRIFT: the total drift in milliseconds of the OBS clock relative to 
the GPS clock, between the time of deployment and the time of recovery (see 
figure).  The Odetics clock calibration is given in terms of GPS time (seconds).  
The notation for GPS clock calibration is the following: 1.000 s equals no 
actual offset, 0.9000 s equals +0.1 s actual offset, and 1.1000 s equals -0.1 s 
actual offset (subtract the calibration value from 1.0 s to obtain the 
offset).For example, the pre-deployment and post deployment calibrations from 
the Odetics box are given as 0.999134 s and 1.000512 s respectively.  Thus the 
corresponding offsets are 0.0008660 s, and -0.000512 s respectively.  The 
difference between these offsets is the 'total clock drift', in this case 
-0.001378 s or -1.378 ms (post-deployment minus pre-deployment offset).  

GUN DELAY: the time delay from when the airguns are signaled to shoot (GPS time), 
and when they actually shoot - is a static time offset in milliseconds (positive).
"""





# Documentation for the regular expressions (raw (r) so I can use backslashes, etc)
regExpHelpText = \
r"""The regular expression editing window allows one to edit a regular expression
which is used to parse the input file line by line.  These are in a pre-expanded
form which allows usto call certain predefined helper matching functions.  The
'View Expanded' button allows one to view the resulting expanded regular expression.

The predefined matching helper functions are:

    matchInt(name)
    matchStr(name)
    matchFloat(name)
    matchLatLon(name)
    

  matchInt matches an integer value with an options sign prefix.
  
  matchStr is used to match a string.  Its only use is to parse the 
  'partialSecs' field seen in the odetics shotlog file.

  matchFloat matches a float value with an optional sign, optional
  pre-decimal value (eg: .012) and optional post-decimal value (eg: 12.).

  matchLatLon matches a lat/long coordinate value in either of the following
  formats:
     +42.157
     42 22.1 N
  Meaning it matches both decimal degree with optional sign,
  as well as degree minute with minute in decimal form, and an optional compass
  direction character (N, E, S, W).  Thus this helper function should match most
  lat/lon coordinates available.


  One references these functions like so:
  
     $helperFunction(arg1, arg2)

One should be able to manage input from various types of input files simply by
rearraging the order that these helper functions are expected.

Regular expressions are used to 'match' expressions.  For example, to match
one or more items of whitespace (spaces, tab, etc) one enters:
    \s+
The '\s' means match whitespace, while the + modifier says 'match the previous
argument 1 or more times'.  Thus the above statement consumes 1 or more pieces of
whitespace.

NOTE: the only optional match name in the shot times is 'nanosec' - if not matched,
it is not used.

If one is using lat/long times from the shot time data, these need not be in the
regular expression match for the navigation data.

To skip data which is not to be considered by the program, simply enter regular
expressions without helper functions.  For example, to skip a real value:

    \d*\.\d*

Consumes 0 or more digits, a decimal place, then 0 or more remaining digits.

Advanced Regular Expression Editing
-----------------------------------

NOTE: These regular expressions are in 'Verbose' mode, meaning that
whitespaces/newlines are insignificant, and comments are allowed. (#comment).

Please reference the following URL's for Python regular expression assistance:
  http://www.python.org/doc/current/lib/module-re.html
  http://py-howto.sourceforge.net/regex/regex.html

For the purpose of matching to specific variables (such as shotNo, lat, lon, etc)
we use 'Named Groups' - meaning we match a set of input, and tag it with a symbolic
name so we can reference it in the loading stage regardless of position.  For example
to match 'shotNo' assuming it is one or more digits only, the expression would look
like:

    (?P<shotNo>\d+)
    
now with an optional sign (characters within sqaure brackets are a 'set' - matches any):

    (?P<shotNo>[+-]?\d+)

Note that this is the actual way we match integers with matchInt().

For a more complicated example, lets say you have day, hour, and minute all
in a field with no space delimeters (but fixed widths) in these formats (day:236, hour:1, min:2):

    2360102
    
    0010102

To match this we need to use braces {} - this matches {min,max} of the previous
elements - since we want a fixed number of digits for each, the min and max
are the same.

Then the corresponding regular expression would look like:

  (?P<day>\d{3,3})
  (?P<hour>\d{2,2})
  (?P<min>\d{2,2})

If there is the potential for whitespace in between these components instead of
0's, as is the case with many Fortran output files, as follows:

  (dddhhmm)
   236 1 2
     1 1 2
   23456 1
or even
   123 212
   

(note that the number of spaces cannot be relied upon)

Then a suitable expression to match the above would be:

  (?P<day>[\d\s]{3,3})
  (?P<hour>[\d\s]{2,2})
  (?P<min>[\d\s]{2,2})

This forces a match of exactly 3 (then 2 then 2) repititions of digits or whitespace -
forcing the 'fixed width' nature of the input data.

For more information, please see the URL's above.
"""
